"""add fields to github_users

Revision ID: c0d8d6a8f071
Revises: 8585129ca524
Create Date: 2020-12-26 15:07:57.347579

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'c0d8d6a8f071'
down_revision = '8585129ca524'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('github_users', schema=None) as batch_op:
        batch_op.add_column(sa.Column('avatar_url', sa.Text(), nullable=True))
        batch_op.add_column(sa.Column('name', sa.Text(), nullable=True))

    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    with op.batch_alter_table('github_users', schema=None) as batch_op:
        batch_op.drop_column('name')
        batch_op.drop_column('avatar_url')

    # ### end Alembic commands ###
