"""add table account_admins

Revision ID: e1d390d440d5
Revises: 4e8693037e72
Create Date: 2021-02-14 20:06:13.923464

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'e1d390d440d5'
down_revision = '4e8693037e72'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('account_admins',
    sa.Column('admin_id', sa.Integer(), nullable=False),
    sa.Column('github_login', sa.Text(), nullable=False),
    sa.PrimaryKeyConstraint('admin_id', name=op.f('pk_account_admins')),
    sa.UniqueConstraint('github_login', name=op.f('uq_account_admins_github_login'))
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('account_admins')
    # ### end Alembic commands ###
